Subject: [PATCH 2/9] rename setup_logical_decoding to repack_setup_logical_decoding

From: Álvaro Herrera <[email-masked]>
Date: Thu, 12 Mar 2026 16:05:01 +0100

---
 src/backend/commands/cluster.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/backend/commands/cluster.c b/src/backend/commands/cluster.c
index da4919e497a..db3980b84f5 100644
--- a/src/backend/commands/cluster.c
+++ b/src/backend/commands/cluster.c
@@ -274,7 +274,7 @@ static List *get_tables_to_repack_partitioned(RepackCommand cmd,
 static bool repack_is_permitted_for_relation(RepackCommand cmd,
 											 Oid relid, Oid userid);
 
-static LogicalDecodingContext *setup_logical_decoding(Oid relid);
+static LogicalDecodingContext *repack_setup_logical_decoding(Oid relid);
 static bool decode_concurrent_changes(LogicalDecodingContext *ctx,
 									  DecodingWorkerShared *shared);
 static void apply_concurrent_changes(BufFile *file, ChangeDest *dest);
@@ -612,7 +612,7 @@ cluster_rel(RepackCommand cmd, Relation OldHeap, Oid indexOid,
 	{
 		/*
 		 * Make sure we have no XID assigned, otherwise call of
 		 * setup_logical_decoding() can cause a deadlock.
 		 *
 		 * The existence of transaction block actually does not imply that XID
 		 * was already assigned, but it very likely is. We might want to check
@@ -2620,7 +2620,7 @@ change_useless_for_repack(XLogRecordBuffer *buf)
  * crash by restarting all the work from scratch).
  */
 static LogicalDecodingContext *
-setup_logical_decoding(Oid relid)
+repack_setup_logical_decoding(Oid relid)
 {
 	Relation	rel;
 	Oid			toastrelid;
@@ -4044,7 +4044,7 @@ repack_worker_internal(dsm_segment *seg)
 	/*
 	 * Prepare to capture the concurrent data changes ourselves.
 	 */
-	decoding_ctx = setup_logical_decoding(shared->relid);
+	decoding_ctx = repack_setup_logical_decoding(shared->relid);
 
 	/* Announce that we're ready. */
 	SpinLockAcquire(&shared->mutex);
@@ -612,7 +612,7 @@ cluster_rel(RepackCommand cmd, Relation OldHeap, Oid indexOid,
 		/*
 		 * Make sure we have no XID assigned, otherwise call of
-		 * setup_logical_decoding() can cause a deadlock.
+		 * repack_setup_logical_decoding() can cause a deadlock.
 		 *
 		 * The existence of transaction block actually does not imply that XID
-- 
2.47.3

--pnppmxqkefjd4hu2
Content-Type: text/plain; charset=utf-8
Content-Disposition: attachment;
	filename="0003-remove-excess-parens-around-ereport.nocfbot.txt"